#!/bin/bash

eval $(docker-machine env interceptor-testing)

docker run -d \
    --net=host \
    --name=zookeeper \
    -v /mnt/zookeeper/data:/var/lib/zookeeper/data \
    -e ZOOKEEPER_CLIENT_PORT=32181 \
    confluentinc/cp-zookeeper:3.3.0 

docker run -d \
    --net=host \
    --name=kafka \
    -v /mnt/kafka/data:/var/lib/kafka/data \
    -e KAFKA_ZOOKEEPER_CONNECT=$(docker-machine ip interceptor-testing):32181 \
    -e KAFKA_LISTENERS=PLAINTEXT://0.0.0.0:29092 \
    -e KAFKA_ADVERTISED_LISTENERS=PLAINTEXT://$(docker-machine ip interceptor-testing):29092 \
    -e KAFKA_OFFSETS_TOPIC_REPLICATION_FACTOR=1 \
    -e KAFKA_BROKER_ID=1 \
    confluentinc/cp-kafka:3.3.0

sleep 5

docker run \
    --net=host \
    --rm \
    confluentinc/cp-kafka:3.3.0 \
    kafka-topics --create --topic test-topic-0 --partitions 3 --replication-factor 1 --if-not-exists --zookeeper $(docker-machine ip interceptor-testing):32181

docker run \
    --net=host \
    --rm \
    confluentinc/cp-kafka:3.3.0 \
    kafka-topics --create --topic test-topic-1 --partitions 10 --replication-factor 1 --if-not-exists --zookeeper $(docker-machine ip interceptor-testing):32181

docker run \
    --net=host \
    --rm \
    confluentinc/cp-kafka:3.3.0 \
    kafka-topics --create --topic test-topic-2 --partitions 120 --replication-factor 1 --if-not-exists --zookeeper $(docker-machine ip interceptor-testing):32181

docker run -d \
  --name=control-center \
  --ulimit nofile=16384:16384 \
  -p 9021:9021 \
  -e CONTROL_CENTER_ZOOKEEPER_CONNECT=$(docker-machine ip interceptor-testing):32181 \
  -e CONTROL_CENTER_BOOTSTRAP_SERVERS=$(docker-machine ip interceptor-testing):29092 \
  -e CONTROL_CENTER_REST_LISTENERS=http://0.0.0.0:9021 \
  -e CONTROL_CENTER_REPLICATION_FACTOR=1 \
  -v /mnt/control-center/data:/var/lib/confluent-control-center \
  docker.confluent.io:5000/confluentinc/cp-enterprise-control-center:latest
