/**
 * Copyright 2017 Confluent Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#include <stdio.h>
#include <inttypes.h>

#include "../tests/monitoring.pb-c.h"

void monitoring_message_print_json (const Monitoring__MonitoringMessage *m) {
        const char *clienttypes[] = { "consumer", "producer", "c3" };
        const char *msgtypes[] = { "normal", "error", "heartbeat" };


#define PR_HAS(FIELD,FMT,VAL) do {                                      \
                        printf(" \"%s\": " FMT ",\n", # FIELD, VAL);    \
        } while (0)

#define PR_STR(FIELD) do {                                              \
                if (m->FIELD)                                           \
                        printf(" \"%s\": \"%s\",\n", # FIELD, m->FIELD); \
        } while (0)

#define PR_I64(FIELD) do {                                              \
                        printf(" \"%s\": %"PRId64",\n", # FIELD, m->FIELD); \
        } while (0)

#define PR_I32(FIELD) do {                                              \
                        printf(" \"%s\": %"PRId32",\n", # FIELD, m->FIELD); \
        } while (0)

#define PR_BOOL(FIELD) do {                                             \
                        printf(" \"%s\": %s,\n", # FIELD,               \
                               m->FIELD ? "true":"false");              \
        } while (0)



        printf("{\n");
        PR_HAS(clienttype, "\"%s\"", clienttypes[m->clienttype]);
        PR_STR(clientid);
        PR_STR(group);
        PR_STR(session);
        PR_I64(sequence);
        PR_I64(window);
        PR_I64(timestamp);
        PR_STR(topic);
        PR_I32(partition);
        PR_I64(count);
        PR_I64(aggregatebytes);
        PR_I32(aggregatecrc);
        PR_I64(totallatency);
        PR_I64(minlatency);
        PR_I64(maxlatency);
        PR_I64(sampleperiod);
        PR_HAS(type, "\"%s\"", msgtypes[m->type]);
        PR_BOOL(shutdown);
        PR_I64(minwindow);
        PR_I64(maxwindow);
        PR_I32(monitoringtopicpartition);
        PR_STR(clusterid);
        PR_STR(clustername);
        PR_I64(arrivaltime);
        printf("}\n");
}
